pub struct SimRng { /* private fields */ }Expand description
Seeded RNG wrapper for deterministic simulation
Implementations
Sourceimpl SimRng
impl SimRng
Sourcepub fn gen_range<T, R>(&mut self, range: R) -> Twhere
T: SampleUniform,
R: SampleRange<T>,
pub fn gen_range<T, R>(&mut self, range: R) -> Twhere
T: SampleUniform,
R: SampleRange<T>,
Generate a random value in the given range
Sourcepub fn gen_bool(&mut self, p: f64) -> bool
pub fn gen_bool(&mut self, p: f64) -> bool
Generate a random bool with the given probability of true
Sourcepub fn exponential(&mut self, rate: f64) -> f64
pub fn exponential(&mut self, rate: f64) -> f64
Generate an exponential random variable
Used for inter-arrival times in Poisson processes. Mean = 1/rate
Sourcepub fn poisson(&mut self, lambda: f64) -> u32
pub fn poisson(&mut self, lambda: f64) -> u32
Generate a Poisson random variable
Returns the number of events in a unit interval given the rate.
Sourcepub fn negbin(&mut self, mean: f64, dispersion: f64) -> u32
pub fn negbin(&mut self, mean: f64, dispersion: f64) -> u32
Generate from a negative binomial distribution
Used for order line counts. Returns at least 1. Uses Gamma-Poisson mixture.
Sourcepub fn zipf(&mut self, n: usize, alpha: f64) -> usize
pub fn zipf(&mut self, n: usize, alpha: f64) -> usize
Generate from a Zipf distribution
Used for SKU popularity. Returns an index in [0, n).
Sourcepub fn lognormal(&mut self, mean: f64, stddev: f64) -> f64
pub fn lognormal(&mut self, mean: f64, stddev: f64) -> f64
Generate a lognormal random variable